"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.onPostBuild = onPostBuild;

var _promises = _interopRequireDefault(require("fs/promises"));

var _generateRobotstxt = _interopRequireDefault(require("generate-robotstxt"));

var _path = _interopRequireDefault(require("path"));

const publicPath = './public';
const defaultEnv = 'development';
const defaultOptions = {
  output: '/robots.txt',
  query: `{
    site {
      siteMetadata {
        siteUrl
      }
    }
  }`
};

function runQuery(handler, query) {
  return handler(query).then(res => {
    if (res.errors) {
      throw new Error(res.errors.join(', '));
    }

    return res.data;
  });
}

const getOptions = pluginOptions => {
  const options = { ...pluginOptions
  };
  delete options.plugins;
  const {
    env = {},
    resolveEnv = () => process.env.GATSBY_ACTIVE_ENV || process.env.NODE_ENV
  } = options;
  const envOptions = env[resolveEnv()] || env[defaultEnv] || {};
  delete options.env;
  delete options.resolveEnv;
  return { ...options,
    ...envOptions
  };
};

async function onPostBuild({
  graphql,
  pathPrefix = ""
}, pluginOptions) {
  const userOptions = getOptions(pluginOptions);
  const mergedOptions = { ...defaultOptions,
    ...userOptions
  };

  if (mergedOptions.host !== null) {
    if (!Object.prototype.hasOwnProperty.call(mergedOptions, 'host')) {
      const {
        site: {
          siteMetadata: {
            siteUrl
          }
        }
      } = await runQuery(graphql, mergedOptions.query);
      mergedOptions.host = siteUrl;
    }
  }

  if (mergedOptions.sitemap !== null) {
    if (!Object.prototype.hasOwnProperty.call(mergedOptions, 'sitemap')) {
      mergedOptions.sitemap = new URL(_path.default.posix.join(pathPrefix, 'sitemap', 'sitemap-index.xml'), mergedOptions.host).toString();
    } else {
      try {
        new URL(mergedOptions.sitemap);
      } catch {
        mergedOptions.sitemap = new URL(mergedOptions.sitemap.startsWith(pathPrefix) ? mergedOptions.sitemap : _path.default.posix.join(pathPrefix, mergedOptions.sitemap), mergedOptions.host).toString();
      }
    }
  }

  const {
    policy,
    sitemap,
    host,
    output,
    configFile
  } = mergedOptions;
  const content = await (0, _generateRobotstxt.default)({
    policy,
    sitemap,
    host,
    configFile
  });

  const filename = _path.default.join(publicPath, output);

  return _promises.default.writeFile(_path.default.resolve(filename), content);
}
//# sourceMappingURL=gatsby-node.js.map